@@ -25,10 +25,11 @@ test_that("correct coord GPS in UTM", {
     correctCoordGPS(projCoord = projCoord, coordRel = coordRel, rangeX = c(0, 100), rangeY = c(0, 100))
   )
   expect_is(corr, "list")
-  expect_length(corr, 3)
-  expect_equal(names(corr), c("cornerCoords", "polygon", "outliers"))
+  expect_length(corr, 4)
+  expect_equal(names(corr), c("cornerCoords", "correctedCoord","polygon", "outliers"))
 
   expect_is(corr$cornerCoords, "data.frame")
+  expect_is(corr$correctedCoord, "data.frame")
   expect_is(corr$polygon, "SpatialPolygons")
   expect_is(corr$outliers, "integer")
 
@@ -58,7 +59,6 @@ test_that("correct coord GPS in UTM", {
     correctCoordGPS(projCoord = projCoord, coordRel = coordRel, rangeX = c(0, 100), rangeY = c(0, 100), rmOutliers = TRUE),
     "Be carefull, you may have GNSS measurement outliers"
   ))
-
   corr_2 <- suppressWarnings(
     correctCoordGPS(
       projCoord = projCoord, coordRel = coordRel, rangeX = c(0, 100), rangeY = c(0, 100),
@@ -89,10 +89,11 @@ test_that("correct coord GPS in long lat", {
     correctCoordGPS(longlat = longlat, coordRel = coordRel, rangeX = c(0, 100), rangeY = c(0, 100))
   )
   expect_is(corr, "list")
-  expect_length(corr, 4)
-  expect_equal(names(corr), c("cornerCoords", "polygon", "outliers", "codeUTM"))
+  expect_length(corr, 5)
+  expect_equal(names(corr), c("cornerCoords", "correctedCoord","polygon", "outliers", "codeUTM"))
 
   expect_is(corr$cornerCoords, "data.frame")
+  expect_is(corr$correctedCoord, "data.frame")
   expect_is(corr$polygon, "SpatialPolygons")
   expect_is(corr$outliers, "integer")
   expect_is(corr$codeUTM, "character")
